# API Reference

Yagra の Python API は、通常 `Yagra.from_workflow(...)` でインスタンスを構築し、`invoke(...)` で実行します。  
CLI 入口は `main()`（`yagra` コマンド）です。

```{eval-rst}
.. automodule:: yagra
   :members:
   :undoc-members:
   :show-inheritance:
```
